pub struct NonMinUsize { /* private fields */ }Expand description
An integer of type usize which is known to not equal usize::MIN.
This type allows for niche filling optimization (similar to the existing std::num::NonZero* types)
meaning items such as Option<NonMinUsize> and Result<NonMinUsize, ()> take up the same
amount of space as usize.
// Create using `new`, extract value using `get`
let x = NonMinUsize::new(123).unwrap();
assert_eq!(x.get(), 123);
// The value cannot be `usize::MIN`
let y = NonMinUsize::new(usize::MIN);
assert_eq!(y, None);
// Niche filling optimization works!
use std::mem::size_of;
assert_eq!(size_of::<usize>(), size_of::<NonMinUsize>());
assert_eq!(size_of::<usize>(), size_of::<Option<NonMinUsize>>());Implementations
Sourceimpl NonMinUsize
impl NonMinUsize
Sourcepub fn new(value: usize) -> Option<Self>
pub fn new(value: usize) -> Option<Self>
Creates an instance of NonMinUsize by checking if the value is not usize::MIN.
Sourcepub unsafe fn new_unchecked(value: usize) -> Self
pub unsafe fn new_unchecked(value: usize) -> Self
Creates an instance of NonMinUsize without checking if the value is not usize::MIN.
Safety
The value cannot be equal to usize::MIN.